# Response Related

Here are the metrics related to response of the RAG model


````{grid}
:gutter: 2

```{grid-item-card} 💡 Response Relevancy
:link: response-relevancy
:link-type: ref

This evaluates how much the answer matches what is needed, showing how appropriate it is.
```

```{grid-item-card} 💡 Response Conciseness
:link: response-conciseness
:link-type: ref

This evaluates the conciseness of a response, ensuring it's short yet contains as much relevant information as possible.
```

````

```{toctree}
:hidden:

response_relevancy
response_conciseness
```